@@ -18,7 +18,7 @@
 #include "theme_preferencesui.h"
 #include "konvisettingspage.h"
 
-#include <kio/job.h>
+#include <tdeio/job.h>
 
 
 class TQStringList;
@@ -26,7 +26,7 @@ class TQStringList;
 class Theme_Config : public Theme_ConfigUI, public KonviSettingsPage
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         explicit Theme_Config(TQWidget* parent, const char* name=NULL);
@@ -46,7 +46,7 @@ class Theme_Config : public Theme_ConfigUI, public KonviSettingsPage
         void updateButtons();
         void installTheme();
         void removeTheme();
-        void postRemoveTheme(KIO::Job* delete_job);
+        void postRemoveTheme(TDEIO::Job* delete_job);
 
     private:
         TQStringList m_dirs;
